## Easy skLearn
This library is base on sklearn, which can be easier to build classification and regressor models



## Install 

```
#pip install easy_sklearn
```


## Usage

```
esc = EasySklearnClassifier()
X_train, X_test, y_train, y_test = esc.split_data(X, y)
esc.set()
esc.fit(X_train, y_train)
esc.score(X_test, y_test)
esc.plot_learning_curve()

```

[Classifier Example]: https://github.com/ruifeng96150/easy_sklearn/demo_classifier.ipynb "Classifier Example"
[Regressor Example]: https://github.com/ruifeng96150/easy_sklearn/demo_regressor.ipynb "Regressor Example"

## Examples
* [Classifier Example],
* [Regressor Example]

## Contribution or Issues
It's project is free to use and is waiting your contribute to make it more easier to use.
